# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKPathPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkContourExtractor2DImageFilterPython
else:
    import _itkContourExtractor2DImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkContinuousIndexPython
import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkRGBAPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.itkImageToPathFilterPython
import itk.itkPathSourcePython
import itk.itkPolyLineParametricPathPython
import itk.itkParametricPathPython
import itk.itkPathBasePython
import itk.itkVectorContainerPython
import itk.itkArrayPython

def itkContourExtractor2DImageFilterIF2_New():
    return itkContourExtractor2DImageFilterIF2.New()

class itkContourExtractor2DImageFilterIF2(itk.itkImageToPathFilterPython.itkImageToPathFilterIF2PLPP2):
    r"""Proxy of C++ itkContourExtractor2DImageFilterIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkContourExtractor2DImageFilterIF2_Pointer"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkContourExtractor2DImageFilterIF2_Pointer"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_Clone(self)

    def SetReverseContourOrientation(self, _arg):
        r"""
        SetReverseContourOrientation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_SetReverseContourOrientation(self, _arg)

    def GetReverseContourOrientation(self):
        r"""GetReverseContourOrientation(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_GetReverseContourOrientation(self)

    def ReverseContourOrientationOn(self):
        r"""ReverseContourOrientationOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_ReverseContourOrientationOn(self)

    def ReverseContourOrientationOff(self):
        r"""ReverseContourOrientationOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_ReverseContourOrientationOff(self)

    def SetVertexConnectHighPixels(self, _arg):
        r"""
        SetVertexConnectHighPixels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_SetVertexConnectHighPixels(self, _arg)

    def GetVertexConnectHighPixels(self):
        r"""GetVertexConnectHighPixels(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_GetVertexConnectHighPixels(self)

    def VertexConnectHighPixelsOn(self):
        r"""VertexConnectHighPixelsOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_VertexConnectHighPixelsOn(self)

    def VertexConnectHighPixelsOff(self):
        r"""VertexConnectHighPixelsOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_VertexConnectHighPixelsOff(self)

    def SetLabelContours(self, _arg):
        r"""
        SetLabelContours(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_SetLabelContours(self, _arg)

    def GetLabelContours(self):
        r"""GetLabelContours(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_GetLabelContours(self)

    def LabelContoursOn(self):
        r"""LabelContoursOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_LabelContoursOn(self)

    def LabelContoursOff(self):
        r"""LabelContoursOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_LabelContoursOff(self)

    def SetRequestedRegion(self, region):
        r"""
        SetRequestedRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_SetRequestedRegion(self, region)

    def GetRequestedRegion(self):
        r"""GetRequestedRegion(self) -> itkImageRegion2"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_GetRequestedRegion(self)

    def ClearRequestedRegion(self):
        r"""ClearRequestedRegion(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_ClearRequestedRegion(self)

    def SetContourValue(self, _arg):
        r"""
        SetContourValue(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_SetContourValue(self, _arg)

    def GetContourValue(self):
        r"""GetContourValue(self) -> double const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_GetContourValue(self)
    DimensionShouldBe2 = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_DimensionShouldBe2
    
    InputPixelTypeComparable = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_InputPixelTypeComparable
    
    InputHasPixelTraitsCheck = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_InputHasPixelTraitsCheck
    
    InputHasNumericTraitsCheck = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkContourExtractor2DImageFilterPython.delete_itkContourExtractor2DImageFilterIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkContourExtractor2DImageFilterIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkContourExtractor2DImageFilterIF2

        Create a new object of the class itkContourExtractor2DImageFilterIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkContourExtractor2DImageFilterIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkContourExtractor2DImageFilterIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkContourExtractor2DImageFilterIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkContourExtractor2DImageFilterIF2 in _itkContourExtractor2DImageFilterPython:
_itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIF2_swigregister(itkContourExtractor2DImageFilterIF2)

def itkContourExtractor2DImageFilterISS2_New():
    return itkContourExtractor2DImageFilterISS2.New()

class itkContourExtractor2DImageFilterISS2(itk.itkImageToPathFilterPython.itkImageToPathFilterISS2PLPP2):
    r"""Proxy of C++ itkContourExtractor2DImageFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkContourExtractor2DImageFilterISS2_Pointer"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkContourExtractor2DImageFilterISS2_Pointer"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_Clone(self)

    def SetReverseContourOrientation(self, _arg):
        r"""
        SetReverseContourOrientation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_SetReverseContourOrientation(self, _arg)

    def GetReverseContourOrientation(self):
        r"""GetReverseContourOrientation(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_GetReverseContourOrientation(self)

    def ReverseContourOrientationOn(self):
        r"""ReverseContourOrientationOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_ReverseContourOrientationOn(self)

    def ReverseContourOrientationOff(self):
        r"""ReverseContourOrientationOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_ReverseContourOrientationOff(self)

    def SetVertexConnectHighPixels(self, _arg):
        r"""
        SetVertexConnectHighPixels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_SetVertexConnectHighPixels(self, _arg)

    def GetVertexConnectHighPixels(self):
        r"""GetVertexConnectHighPixels(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_GetVertexConnectHighPixels(self)

    def VertexConnectHighPixelsOn(self):
        r"""VertexConnectHighPixelsOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_VertexConnectHighPixelsOn(self)

    def VertexConnectHighPixelsOff(self):
        r"""VertexConnectHighPixelsOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_VertexConnectHighPixelsOff(self)

    def SetLabelContours(self, _arg):
        r"""
        SetLabelContours(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_SetLabelContours(self, _arg)

    def GetLabelContours(self):
        r"""GetLabelContours(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_GetLabelContours(self)

    def LabelContoursOn(self):
        r"""LabelContoursOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_LabelContoursOn(self)

    def LabelContoursOff(self):
        r"""LabelContoursOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_LabelContoursOff(self)

    def SetRequestedRegion(self, region):
        r"""
        SetRequestedRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_SetRequestedRegion(self, region)

    def GetRequestedRegion(self):
        r"""GetRequestedRegion(self) -> itkImageRegion2"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_GetRequestedRegion(self)

    def ClearRequestedRegion(self):
        r"""ClearRequestedRegion(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_ClearRequestedRegion(self)

    def SetContourValue(self, _arg):
        r"""
        SetContourValue(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_SetContourValue(self, _arg)

    def GetContourValue(self):
        r"""GetContourValue(self) -> double const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_GetContourValue(self)
    DimensionShouldBe2 = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_DimensionShouldBe2
    
    InputPixelTypeComparable = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_InputPixelTypeComparable
    
    InputHasPixelTraitsCheck = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_InputHasPixelTraitsCheck
    
    InputHasNumericTraitsCheck = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkContourExtractor2DImageFilterPython.delete_itkContourExtractor2DImageFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkContourExtractor2DImageFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkContourExtractor2DImageFilterISS2

        Create a new object of the class itkContourExtractor2DImageFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkContourExtractor2DImageFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkContourExtractor2DImageFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkContourExtractor2DImageFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkContourExtractor2DImageFilterISS2 in _itkContourExtractor2DImageFilterPython:
_itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterISS2_swigregister(itkContourExtractor2DImageFilterISS2)

def itkContourExtractor2DImageFilterIUC2_New():
    return itkContourExtractor2DImageFilterIUC2.New()

class itkContourExtractor2DImageFilterIUC2(itk.itkImageToPathFilterPython.itkImageToPathFilterIUC2PLPP2):
    r"""Proxy of C++ itkContourExtractor2DImageFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkContourExtractor2DImageFilterIUC2_Pointer"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkContourExtractor2DImageFilterIUC2_Pointer"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_Clone(self)

    def SetReverseContourOrientation(self, _arg):
        r"""
        SetReverseContourOrientation(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_SetReverseContourOrientation(self, _arg)

    def GetReverseContourOrientation(self):
        r"""GetReverseContourOrientation(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_GetReverseContourOrientation(self)

    def ReverseContourOrientationOn(self):
        r"""ReverseContourOrientationOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_ReverseContourOrientationOn(self)

    def ReverseContourOrientationOff(self):
        r"""ReverseContourOrientationOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_ReverseContourOrientationOff(self)

    def SetVertexConnectHighPixels(self, _arg):
        r"""
        SetVertexConnectHighPixels(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_SetVertexConnectHighPixels(self, _arg)

    def GetVertexConnectHighPixels(self):
        r"""GetVertexConnectHighPixels(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_GetVertexConnectHighPixels(self)

    def VertexConnectHighPixelsOn(self):
        r"""VertexConnectHighPixelsOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_VertexConnectHighPixelsOn(self)

    def VertexConnectHighPixelsOff(self):
        r"""VertexConnectHighPixelsOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_VertexConnectHighPixelsOff(self)

    def SetLabelContours(self, _arg):
        r"""
        SetLabelContours(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_SetLabelContours(self, _arg)

    def GetLabelContours(self):
        r"""GetLabelContours(self) -> bool const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_GetLabelContours(self)

    def LabelContoursOn(self):
        r"""LabelContoursOn(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_LabelContoursOn(self)

    def LabelContoursOff(self):
        r"""LabelContoursOff(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_LabelContoursOff(self)

    def SetRequestedRegion(self, region):
        r"""
        SetRequestedRegion(self, region)

        Parameters
        ----------
        region: itkImageRegion2 const

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_SetRequestedRegion(self, region)

    def GetRequestedRegion(self):
        r"""GetRequestedRegion(self) -> itkImageRegion2"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_GetRequestedRegion(self)

    def ClearRequestedRegion(self):
        r"""ClearRequestedRegion(self)"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_ClearRequestedRegion(self)

    def SetContourValue(self, _arg):
        r"""
        SetContourValue(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_SetContourValue(self, _arg)

    def GetContourValue(self):
        r"""GetContourValue(self) -> double const &"""
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_GetContourValue(self)
    DimensionShouldBe2 = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_DimensionShouldBe2
    
    InputPixelTypeComparable = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_InputPixelTypeComparable
    
    InputHasPixelTraitsCheck = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_InputHasPixelTraitsCheck
    
    InputHasNumericTraitsCheck = _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkContourExtractor2DImageFilterPython.delete_itkContourExtractor2DImageFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkContourExtractor2DImageFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkContourExtractor2DImageFilterIUC2

        Create a new object of the class itkContourExtractor2DImageFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkContourExtractor2DImageFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkContourExtractor2DImageFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkContourExtractor2DImageFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkContourExtractor2DImageFilterIUC2 in _itkContourExtractor2DImageFilterPython:
_itkContourExtractor2DImageFilterPython.itkContourExtractor2DImageFilterIUC2_swigregister(itkContourExtractor2DImageFilterIUC2)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def contour_extractor2_d_image_filter(*args: itkt.ImageLike,  reverse_contour_orientation: bool=..., vertex_connect_high_pixels: bool=..., label_contours: bool=..., requested_region: itkt.ImageRegion=..., contour_value: float=...,**kwargs)-> itkt.PathSourceReturn:
    """Functional interface for ContourExtractor2DImageFilter"""
    import itk

    kwarg_typehints = { 'reverse_contour_orientation':reverse_contour_orientation,'vertex_connect_high_pixels':vertex_connect_high_pixels,'label_contours':label_contours,'requested_region':requested_region,'contour_value':contour_value }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ContourExtractor2DImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def contour_extractor2_d_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKPath.ContourExtractor2DImageFilter
    contour_extractor2_d_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    contour_extractor2_d_image_filter.__doc__ = filter_object.__doc__



